import React, { useState, useRef } from "react";
import { Form, Input, Button, Space, Table, Menu, Image } from "antd";
import {
  Routes,
  Route,
  Navigate,
  useNavigate,
  useLocation,
} from "react-router-dom";

const CommentsReviewContent = (props) => {
  const current = props.current;
  //表头
  const columns = [
    {
      title: "用户ID",
      dataIndex: "id",
      key: "id",
    },
    {
      title: "用户昵称",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "订单号",
      dataIndex: "orderId",
      key: "orderId",
    },
    {
      title: "评分",
      dataIndex: "rate",
      key: "rate",
    },
    {
      title: "评语",
      dataIndex: "comment",
      key: "comment",
    },
    {
      title: "提交时间",
      dataIndex: "submitTime",
      key: "submitTime",
    },
    {
      title: "Reaction",
      dataIndex: "reaction",
      key: "reaction",
      render: (reaction) => (
        <div>
          {reaction
            ? reaction.map((item) =>
                item.type === "img" ? (
                  <Image
                    key={item.url}
                    src={item.url}
                    width={150}
                    style={{ marginBottom: 10 }}
                  />
                ) : (
                  <video key={item.url} src={item.url} width={150} controls />
                )
              )
            : "无"}
        </div>
      ),
    },
    {
      title: "操作",
      dataIndex: "opeartion",
      key: "opeartion",
      render: (_, record) => (
        <div>
          <Space>
            <Button type="primary" onClick={() => onClickSubmit(record)}>
              通过
            </Button>
            {current !== "denied" && (
              <Button onClick={() => onClickDenied(record)}>违规</Button>
            )}
          </Space>
        </div>
      ),
    },
  ];
  if (current === "reaction") {
    columns.splice(7, 1);
  }
  //给表单绑定ref
  const formRef = useRef(null);
  //点击通过按钮
  const onClickSubmit = (record) => {
    formRef.current.key = record.key;
    formRef.current.btn = "pass";
    formRef.current.submit();
  };
  //点击未符合按钮
  const onClickDenied = (record) => {
    formRef.current.key = record.key;
    formRef.current.btn = "denied";
    formRef.current.submit();
  };
  //提交表单
  const handleSubmit = () => {
    //要提交的数据
    let status;
    if (formRef.current.btn === "denied") {
      status = "denied";
    } else {
      status = "pass";
    }
    const submitData = {
      key: formRef.current.key,
      status: status,
    };
    //提交数据
    console.log(submitData);
    //取消数据展示
    setShowData(showData.filter((item) => item.key !== submitData.key));
  };
  //全部数据
  let data = [
    {
      key: "1",
      id: "123456",
      name: "马牛逼",
      orderId: "666666666666",
      rate: "5.0",
      comment: "马牛逼的评语",
      submitTime: "2023-7-20 21:00",
      reaction: [
        {
          type: "img",
          url: "https://s2.loli.net/2023/07/25/fjouqVLAlTn2s58.png",
        },
      ],
      status: "pending",
    },
    {
      key: "2",
      id: "10086",
      name: "迪迦",
      orderId: "9999999999999",
      rate: "4.0",
      comment: "迪迦的评语",
      submitTime: "2023-7-20 20:59",
      reaction: [
        {
          type: "img",
          url: "https://s2.loli.net/2023/07/25/1daCqmZGQNUzoJ8.png",
        },
        {
          type: "video",
          url: "https://media.w3.org/2010/05/sintel/trailer.mp4",
        },
      ],
      remark: "迪迦的备注",
      status: "pending",
    },
  ];
  //展示的数据
  const [showData, setShowData] = useState(data);
  //搜索用户
  const search = (value) => {
    value.name || value.id || value.orderId
      ? setShowData(
          data.filter(
            (item) =>
              item.name === value.name ||
              item.id === value.id ||
              item.orderId === value.orderId
          )
        )
      : setShowData(data);
  };
  //表单提交失败
  const onFinishFailed = (errorInfo) => {
    console.log("Failed:", errorInfo);
  };
  return (
    <div style={{ marginLeft: 20, marginRight: 20 }}>
      <p>
        {current === "pending" && `待处理${showData.length}条`}
        {current === "denied" && `未通过${showData.length}条`}
        {current === "reaction" && `包含reaction的评价共${showData.length}条`}
      </p>
      <Form name="search" onFinish={search} onFinishFailed={onFinishFailed}>
        <Space style={{ marginBottom: 20 }}>
          <Form.Item label="订单号" name="orderId" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Form.Item label="用户ID" name="id" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Form.Item label="用户昵称" name="name" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Button type="primary" htmlType="submit">
            搜索
          </Button>
        </Space>
      </Form>
      <Form
        ref={formRef}
        name="remark"
        onFinish={handleSubmit}
        onFinishFailed={onFinishFailed}
      >
        <Table
          columns={columns}
          dataSource={showData}
          pagination={{ pageSize: 20 }}
          scroll={{ y: window.innerHeight - 300 }}
        />
      </Form>
    </div>
  );
};

export default function CommentsReview() {
  const navigate = useNavigate();
  //当前tab
  const location = useLocation();
  const pathname = location.pathname.split("/")[2] || "pending";
  const [current, setCurrent] = useState(pathname);
  //tab名称
  const items = [
    {
      label: "待处理",
      key: "pending",
    },
    {
      label: "未通过",
      key: "denied",
    },
    {
      label: "Reaction",
      key: "reaction",
    },
  ];
  const onClick = (e) => {
    setCurrent(e.key);
    navigate(e.key);
  };

  return (
    <div>
      <Menu
        onClick={onClick}
        selectedKeys={[current]}
        mode="horizontal"
        items={items}
      />
      <Routes>
        <Route path="/" element={<Navigate to="/commentsReview/pending" />} />
        <Route
          path="/pending"
          element={<CommentsReviewContent current="pending" />}
        />
        <Route
          path="/denied"
          element={<CommentsReviewContent current="denied" />}
        />
        <Route
          path="/reaction"
          element={<CommentsReviewContent current="reaction" />}
        />
      </Routes>
    </div>
  );
}
