import React, { useState, useRef } from "react";
import { Form, Input, Button, Space, Table, Menu, Image } from "antd";
import { Routes, Route, Navigate, useNavigate,useLocation } from "react-router-dom";

const FeedbackContent = (props) => {
  const { TextArea } = Input;
  const current = props.current;
  //表头
  const columns = [
    {
      title: "用户ID",
      dataIndex: "id",
      key: "id",
    },
    {
      title: "用户昵称",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "反馈描述",
      dataIndex: "description",
      key: "description",
    },
    {
      title: "辅助材料",
      dataIndex: "mediaInfo",
      key: "mediaInfo",
      render: (mediaInfo) => (
        <div>
          {mediaInfo
            ? mediaInfo.map((item) =>
                item.type === "img" ? (
                  <Image
                    key={item.url}
                    src={item.url}
                    width={150}
                    style={{ marginBottom: 10 }}
                  />
                ) : (
                  <video key={item.url} src={item.url} width={150} controls />
                )
              )
            : "无"}
        </div>
      ),
    },
    {
      title: "联系方式",
      dataIndex: "contact",
      key: "contact",
    },
    {
      title: "提交时间",
      dataIndex: "submitTime",
      key: "submitTime",
    },
    {
      title: "备注",
      dataIndex: "remark",
      key: "remark",
      render: (_, record) => (
        <Form.Item name={record.key} initialValue={record.remark}>
          <TextArea rows={4} />
        </Form.Item>
      ),
    },
    {
      title: "操作",
      dataIndex: "opeartion",
      key: "opeartion",
      render: (_, record) => (
        <div>
          <Space>
            <Space.Compact direction="vertical">
              <Button type="primary" onClick={() => onClickSubmit(record)}>
                {current === "pending" && "跟进"}
                {current === "inProgress" && "归档"}
                {current === "done" && "跟进"}
                {current === "invalid" && "跟进"}
                {current === "iteration" && "归档"}
              </Button>
              {current !== "invalid" && (
                <Button onClick={() => onClickInvalid(record)}>无效</Button>
              )}
              {(current === "pending" || current === "inProgress") && (
                <Button onClick={() => onClickIteration(record)}>
                  设为迭代
                </Button>
              )}
            </Space.Compact>
          </Space>
        </div>
      ),
    },
  ];
  //给表单绑定ref
  const formRef = useRef(null);
  //点击修改状态按钮
  const onClickSubmit = (record) => {
    formRef.current.key = record.key;
    formRef.current.btn = "submit";
    formRef.current.submit();
  };
  //点击无效按钮
  const onClickInvalid = (record) => {
    formRef.current.key = record.key;
    formRef.current.btn = "invalid";
    formRef.current.submit();
  };
  //点击迭代相关按钮
  const onClickIteration = (record) => {
    formRef.current.key = record.key;
    formRef.current.btn = "iteration";
    formRef.current.submit();
  };
  //提交表单
  const handleSubmit = (value) => {
    //要提交的数据
    let status;
    if (formRef.current.btn === "invalid") {
      status = "invalid";
    } else if (formRef.current.btn === "iteration") {
      status = "iteration";
    } else {
      switch (current) {
        case "pending":
          status = "inProgress";
          break;
        case "inProgress":
          status = "done";
          break;
        case "done":
          status = "inProgress";
          break;
        case "invalid":
          status = "inProgress";
          break;
        case "iteration":
          status = "done";
          break;
        default:
          break;
      }
    }
    const submitData = {
      key: formRef.current.key,
      remark: value[formRef.current.key],
      status: status,
    };
    //提交数据
    console.log(submitData);
    //取消数据展示
    setShowData(showData.filter((item) => item.key !== submitData.key));
  };
  //全部数据
  let data = [
    {
      key: "1",
      id: "123456",
      name: "马牛逼",
      description:
        "马牛逼反馈马牛逼反馈马牛逼反馈马牛逼反馈马牛逼反馈马牛逼反馈马牛逼反馈马牛逼反馈",
      mediaInfo: [
        {
          type: "img",
          url: "https://s2.loli.net/2023/07/25/fjouqVLAlTn2s58.png",
        },
        {
          type: "video",
          url: "http://clips.vorwaerts-gmbh.de/big_buck_bunny.mp4",
        },
      ],
      contact: "qq:123456789;wx:987654321",
      submitTime: "2023-7-21 21:00",
      remark: "马牛逼的备注",
      status: "pending",
    },
    {
      key: "2",
      id: "10086",
      name: "迪迦",
      description:
        "迪迦反馈迪迦反馈迪迦反馈迪迦反馈迪迦反馈迪迦反馈迪迦反馈迪迦反馈迪迦反馈迪迦反馈",
      mediaInfo: [
        {
          type: "img",
          url: "https://s2.loli.net/2023/07/25/1daCqmZGQNUzoJ8.png",
        },
        {
          type: "video",
          url: "https://media.w3.org/2010/05/sintel/trailer.mp4",
        },
      ],
      contact: "qq:741741;wx:147147",
      submitTime: "2023-7-22 20:59",
      remark: "迪迦的备注",
      status: "pending",
    },
  ];
  //展示的数据
  const [showData, setShowData] = useState(data);
  //搜索名人
  const search = (value) => {
    value.name||value.id
      ? setShowData(data.filter((item) => item.name === value.name||item.id===value.id))
      : setShowData(data);
  };
  //表单提交失败
  const onFinishFailed = (errorInfo) => {
    console.log("Failed:", errorInfo);
  };
  return (
    <div style={{ marginLeft: 20, marginRight: 20 }}>
      <p>
        {current === "pending" && `待处理${showData.length}条`}
        {current === "inProgress" && `跟进中${showData.length}条`}
        {current === "done" && `已处理${showData.length}条`}
        {current === "invalid" && `无效反馈${showData.length}条`}
        {current === "iteration" && `迭代相关${showData.length}条`}
      </p>
      <Form name="search" onFinish={search} onFinishFailed={onFinishFailed}>
        <Space style={{ marginBottom: 20 }}>
        <Form.Item label="用户ID" name="id" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Form.Item label="用户昵称" name="name" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Button type="primary" htmlType="submit">
            搜索
          </Button>
        </Space>
      </Form>
      <Form
        ref={formRef}
        name="remark"
        onFinish={handleSubmit}
        onFinishFailed={onFinishFailed}
      >
        <Table
          columns={columns}
          dataSource={showData}
          pagination={{ pageSize: 20 }}
          scroll={{ y: window.innerHeight - 300 }}
        />
      </Form>
    </div>
  );
};

export default function Feedback() {
  const navigate = useNavigate();
  //当前tab
  const location = useLocation();
  const pathname = location.pathname.split("/")[2]||"pending";
  const [current, setCurrent] = useState(pathname);
  //tab名称
  const items = [
    {
      label: "待处理",
      key: "pending",
    },
    {
      label: "跟进中",
      key: "inProgress",
    },
    {
      label: "已处理",
      key: "done",
    },
    {
      label: "无效反馈",
      key: "invalid",
    },
    {
      label: "迭代相关",
      key: "iteration",
    },
  ];
  const onClick = (e) => {
    setCurrent(e.key);
    navigate(e.key);
  };

  return (
    <div>
      <Menu
        onClick={onClick}
        selectedKeys={[current]}
        mode="horizontal"
        items={items}
      />
      <Routes>
        <Route path="/" element={<Navigate to="/feedback/pending" />} />
        <Route
          path="/pending"
          element={<FeedbackContent current="pending" />}
        />
        <Route
          path="/inProgress"
          element={<FeedbackContent current="inProgress" />}
        />
        <Route path="/done" element={<FeedbackContent current="done" />} />
        <Route
          path="/invalid"
          element={<FeedbackContent current="invalid" />}
        />
        <Route
          path="/iteration"
          element={<FeedbackContent current="iteration" />}
        />
      </Routes>
    </div>
  );
}
