import React, { useState } from "react";
import { Form, Input, Button, Space, Table, Checkbox, Image } from "antd";

export default function OrdersQuerry() {
  //展示的表头
  const [showColumns, setShowColumns] = useState([
    "orderId",
    "orderStatus",
    "orderTime",
    "creatorId",
    "creatorName",
    "userId",
    "userName",
    "requirement",
    "payment",
    "comment",
  ]);
  //动态的表头
  const dynamicColumns = showColumns.map((item) => {
    switch (item) {
      case "orderId":
        return {
          title: "订单号",
          dataIndex: "orderId",
          key: "orderId",
        };
      case "orderStatus":
        return {
          title: "订单状态",
          dataIndex: "orderStatus",
          key: "orderStatus",
        };
      case "orderTime":
        return {
          title: "订单时间",
          dataIndex: "orderTime",
          key: "orderTime",
          render: (orderTime) => (
            <ul>
              <li>
                <span style={{ color: "red" }}>创建时间：</span>
                {orderTime.createTime}
              </li>
              <li>
                <span style={{ color: "red" }}>付款时间：</span>
                {orderTime.payTime}
              </li>
              <li>
                <span style={{ color: "red" }}>发货时间：</span>
                {orderTime.deliveryTime}
              </li>
              <li>
                <span style={{ color: "red" }}>完成时间：</span>
                {orderTime.finishTime}
              </li>
            </ul>
          ),
        };
      case "creatorId":
        return {
          title: "名人ID",
          dataIndex: "creatorId",
          key: "creatorId",
        };
      case "creatorName":
        return {
          title: "名人昵称",
          dataIndex: "creatorName",
          key: "creatorName",
        };
      case "userId":
        return {
          title: "用户ID",
          dataIndex: "userId",
          key: "userId",
        };
      case "userName":
        return {
          title: "用户昵称",
          dataIndex: "userName",
          key: "userName",
        };
      case "requirement":
        return {
          title: "拍摄要求",
          dataIndex: "requirement",
          key: "requirement",
          render: (requirement) => (
            <ul>
              <li>
                <span style={{ color: "red" }}>给谁：</span>
                {requirement.to}
              </li>
              <li>
                <span style={{ color: "red" }}>拍摄要求：</span>
                {requirement.requirement}
              </li>
              <li>
                <span style={{ color: "red" }}>备注：</span>
                {requirement.remark}
              </li>
            </ul>
          ),
        };
      case "payment":
        return {
          title: "实付款",
          dataIndex: "payment",
          key: "payment",
        };
      case "media":
        return {
          title: "成品",
          dataIndex: "media",
          key: "media",
          render: (media) =>
            media.type === "img" ? (
              <Image
                key={media.url}
                src={media.url}
                width={150}
                style={{ marginBottom: 10 }}
              />
            ) : (
              <video key={media.url} src={media.url} width={150} controls />
            ),
        };
      case "comment":
        return {
          title: "评价",
          dataIndex: "comment",
          key: "comment",
          render: (comment) => (
            <ul>
              <li>
                <span style={{ color: "red" }}>评分：</span>
                {comment.rate}
              </li>
              <li>
                <span style={{ color: "red" }}>评语：</span>
                {comment.comment}
              </li>
            </ul>
          ),
        };
      case "reaction":
        return {
          title: "Reaction",
          dataIndex: "reaction",
          key: "reaction",
          render: (reaction) => (
            <div>
              {reaction
                ? reaction.map((item) =>
                    item.type === "img" ? (
                      <Image
                        key={item.url}
                        src={item.url}
                        width={150}
                        style={{ marginBottom: 10 }}
                      />
                    ) : (
                      <video
                        key={item.url}
                        src={item.url}
                        width={150}
                        controls
                      />
                    )
                  )
                : "无"}
            </div>
          ),
        };
      default:
        return {};
    }
  });
  //全部数据
  const data = [
    {
      key: "1",
      orderId: "666666666",
      orderStatus: "已完成",
      orderTime: {
        createTime: "2022-07-25 12:00:00",
        payTime: "2022-07-25 12:01:00",
        deliveryTime: "2022-07-26 12:02:00",
        finishTime: "2022-07-25 12:03:00",
      },
      creatorId: "123456",
      creatorName: "马牛逼",
      userId: "888888",
      userName: "路人甲",
      requirement: {
        to: "路人A",
        requirement: "马牛逼的拍摄要求",
        remark: "马牛逼的备注",
      },
      payment: 60,
      media: {
        type: "img",
        url: "https://s2.loli.net/2023/07/25/fjouqVLAlTn2s58.png",
      },
      comment: { rate: "5.0", comment: "马牛逼的评价" },
      reaction: [
        {
          type: "img",
          url: "https://s2.loli.net/2023/07/25/fjouqVLAlTn2s58.png",
        },
      ],
    },
    {
      key: "2",
      orderId: "999999999",
      orderStatus: "已完成",
      orderTime: {
        createTime: "2023-07-25 12:00:00",
        payTime: "2023-07-25 12:01:00",
        deliveryTime: "2023-07-26 12:02:00",
        finishTime: "2023-07-25 12:03:00",
      },
      creatorId: "10086",
      creatorName: "迪迦",
      userId: "111111",
      userName: "路人乙",
      requirement: {
        to: "路人B",
        requirement: "迪迦的拍摄要求",
        remark: "迪迦的备注",
      },
      payment: 50,
      media: {
        type: "video",
        url: "https://media.w3.org/2010/05/sintel/trailer.mp4",
      },
      comment: { rate: "4.0", comment: "迪迦的评价" },
      reaction: [
        {
          type: "img",
          url: "https://s2.loli.net/2023/07/25/1daCqmZGQNUzoJ8.png",
        },
        {
          type: "video",
          url: "https://media.w3.org/2010/05/sintel/trailer.mp4",
        },
      ],
    },
  ];
  //表头可见性表单的checkbox选项
  const showColumnsOptions = [
    {
      label: "订单号",
      value: "orderId",
    },
    {
      label: "订单状态",
      value: "orderStatus",
    },
    {
      label: "订单时间",
      value: "orderTime",
    },
    {
      label: "名人ID",
      value: "creatorId",
    },
    {
      label: "名人昵称",
      value: "creatorName",
    },
    {
      label: "用户ID",
      value: "userId",
    },
    {
      label: "用户昵称",
      value: "userName",
    },
    {
      label: "拍摄要求",
      value: "requirement",
    },
    {
      label: "实付款",
      value: "payment",
    },
    {
      label: "成品",
      value: "media",
    },
    {
      label: "评价",
      value: "comment",
    },
    {
      label: "Reaction",
      value: "reaction",
    },
  ];
  //展示的数据
  const [showData, setShowData] = useState(data);
  //搜索名人
  const search = (value) => {
    value.creatorName ||
    value.creatorId ||
    value.orderId ||
    value.userId ||
    value.userName
      ? setShowData(
          data.filter(
            (item) =>
              item.creatorName === value.creatorName ||
              item.creatorId === value.creatorId ||
              item.orderId === value.orderId ||
              item.userId === value.userId ||
              item.userName === value.userName
          )
        )
      : setShowData(data);
  };
  //表单提交失败
  const onFinishFailed = (errorInfo) => {
    console.log("Failed:", errorInfo);
  };
  return (
    <div style={{ marginLeft: 20, marginRight: 20 }}>
      <div style={{ marginTop: 20, marginBottom: 10 }}>
        <p style={{ display: "inline" }}>数据可见性：</p>
        <Checkbox.Group
          options={showColumnsOptions}
          defaultValue={showColumns}
          onChange={(value) => setShowColumns(value)}
        />
      </div>
      <Form name="search" onFinish={search} onFinishFailed={onFinishFailed}>
        <Space style={{ marginBottom: 20 }}>
          <Form.Item label="订单号" name="orderId" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Form.Item label="名人ID" name="creatorId" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Form.Item label="名人昵称" name="creatorName" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Form.Item label="用户ID" name="userId" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Form.Item label="用户昵称" name="userName" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Button type="primary" htmlType="submit">
            搜索
          </Button>
        </Space>
      </Form>
      <Table
        columns={dynamicColumns}
        dataSource={showData}
        pagination={{ pageSize: 20 }}
        scroll={{ y: window.innerHeight - 300 }}
      />
    </div>
  );
}
