import React, { useState, useEffect } from "react";
import {
  Form,
  Input,
  Button,
  Space,
  Table,
  Checkbox,
  InputNumber,
  Image,
} from "antd";
import { MinusCircleOutlined, PlusOutlined } from "@ant-design/icons";
import Modal from "../../components/Modal";
import VideoUploader from "../../components/VideoUploader";
import baseRequest from "../../utils/baseRequest";

//tab内容
const GoodsContent = () => {
  const { TextArea } = Input;
  //展示的表头
  const [showColumns, setShowColumns] = useState([
    "baseInfo",
    "displayInfo",
    "shareRatio",
    "platform",
    "displayPoster",
    "displayVideo",
    "displayGallery",
    "remark",
  ]);
  //动态的表头
  const dynamicColumns = showColumns.map((item) => {
    switch (item) {
      case "baseInfo":
        return {
          title: "基础信息",
          dataIndex: "baseInfo",
          key: "baseInfo",
          render: (data) => (
            <div>
              <Image src={data.avatar} width={50} />
              <p>
                mid：<span className="text-red-400">{data.mid}</span>
              </p>
              <p>
                昵称：<span className="text-red-400">{data.name}</span>
              </p>
              <p>
                联系方式：<span className="text-red-400">{data.contact}</span>
              </p>
              <p>
                入驻时间：<span className="text-red-400">{data.joinTime}</span>
              </p>
            </div>
          ),
        };
      case "displayInfo":
        return {
          title: "个人展示信息",
          dataIndex: "displayInfo",
          key: "displayInfo",
          render: (data) => (
            <div>
              <p>
                全网粉丝：<span className="text-red-400">{data.fans}万</span>
              </p>
              <p>
                微信：<span className="text-red-400">{data.wechat}</span>
              </p>
              <p>
                个性签名：<span className="text-red-400">{data.signature}</span>
              </p>
              <p>
                年龄：<span className="text-red-400">{data.age}</span>
              </p>
              <p>
                身高：<span className="text-red-400">{data.height}</span>
              </p>
              <p>
                体重：<span className="text-red-400">{data.weight}</span>
              </p>
              <p>
                星座：<span className="text-red-400">{data.constellation}</span>
              </p>
              <p>
                居住地：<span className="text-red-400">{data.location}</span>
              </p>
            </div>
          ),
        };
      case "shareRatio":
        return {
          title: "分成比例",
          dataIndex: "shareRatio",
          key: "shareRatio",
          render: (data) => <p>{data}%</p>,
        };
      case "platform":
        return {
          title: "平台",
          dataIndex: "platform",
          key: "platform",
          render: (data) => (
            <div>
              <ol>
                {data.map((item) => (
                  <li key={item.name}>
                    <a href={item.url} target="_blank" rel="noreferrer">
                      {item.name}：{item.id}
                    </a>
                  </li>
                ))}
              </ol>
            </div>
          ),
        };
      case "displayPoster":
        return {
          title: "封面图片",
          dataIndex: "displayPoster",
          key: "displayPoster",
          render: (data) => <Image src={data} width={100} />,
        };
      case "displayVideo":
        return {
          title: "封面视频",
          dataIndex: "displayVideo",
          key: "displayVideo",
          render: (data) => <video src={data} width={150} controls />,
        };
      case "displayGallery":
        return {
          title: "相册",
          dataIndex: "displayGallery",
          key: "displayGallery",
          render: (data) => (
            <div>
              {data.map((item) => (
                <Image
                  key={item}
                  src={item}
                  width={100}
                  style={{ marginBottom: 10 }}
                />
              ))}
            </div>
          ),
        };
      case "remark":
        return {
          title: "备注",
          dataIndex: "remark",
          key: "remark",
        };
      default:
        return {};
    }
  });
  dynamicColumns.push({
    title: "操作",
    dataIndex: "opeartion",
    key: "opeartion",
    render: (_, record) => (
      <div>
        <Button type="primary" onClick={() => handleModal(record)}>
          修改
        </Button>
      </div>
    ),
  });
  //全部数据
  const data = [
    {
      key: "1",
      baseInfo: {
        mid: "654321",
        name: "马牛逼",
        avatar: "https://s2.loli.net/2023/07/25/fjouqVLAlTn2s58.png",
        contact: "wx:woshimaniubi",
        joinTime: "2023-09-22 20:00",
      },
      displayInfo: {
        fans: 1000,
        wechat: "maniubi",
        signature: "马牛逼的个性签名",
        age: "21",
        height: "175",
        weight: "75",
        constellation: "天蝎座",
        location: "四川",
      },
      shareRatio: 20,
      platform: [
        {
          index: 1,
          name: "抖音",
          id: "马牛逼",
          url: "https://www.douyin.com/discover",
        },
        {
          index: 2,
          name: "哔哩哔哩",
          id: "马牛逼",
          url: "https://www.bilibili.com",
        },
      ],
      displayPoster: "https://s2.loli.net/2023/07/25/fjouqVLAlTn2s58.png",
      displayVideo: "http://clips.vorwaerts-gmbh.de/big_buck_bunny.mp4",
      displayGallery: [
        "https://s2.loli.net/2023/07/25/fjouqVLAlTn2s58.png",
        "https://s2.loli.net/2023/07/25/1daCqmZGQNUzoJ8.png",
      ],
      remark: "马牛逼的备注",
    },
    {
      key: "2",
      baseInfo: {
        mid: "10086",
        name: "迪迦",
        avatar: "https://s2.loli.net/2023/07/25/1daCqmZGQNUzoJ8.png",
        contact: "wx:woshidijia",
        joinTime: "2023-09-21 20:00",
      },
      displayInfo: {
        fans: 2000,
        wechat: "dijia",
        signature: "迪迦的个性签名",
        age: "88",
        height: "170",
        weight: "70",
        constellation: "处女座",
        location: "上海",
      },
      shareRatio: 20,
      platform: [
        {
          name: "抖音",
          id: "迪迦",
          url: "https://www.douyin.com/discover",
        },
        {
          name: "哔哩哔哩",
          id: "迪迦",
          url: "https://www.bilibili.com",
        },
      ],
      displayPoster: "https://s2.loli.net/2023/07/25/1daCqmZGQNUzoJ8.png",
      displayVideo: "https://media.w3.org/2010/05/sintel/trailer.mp4",
      displayGallery: [
        "https://s2.loli.net/2023/07/25/1daCqmZGQNUzoJ8.png",
        "https://s2.loli.net/2023/07/25/fjouqVLAlTn2s58.png",
      ],
      remark: "迪迦的备注",
    },
  ];

  //获取页面数据
  // const [pageData, setPageData] = useState([]);
  // useEffect(() => {
  //   const getData = async () => {
  //     try {
  //       const base = baseRequest();
  //       const response = await fetch("/op/streamer/list", {
  //         method: "POST",
  //         headers: {
  //           "Content-Type": "application/json",
  //         },
  //         body: JSON.stringify({
  //           mid: 12,
  //           ...base,
  //         }),
  //       });
  //       const temData = await response.json();
  //       console.log(temData);
  //       if (temData.ret === -1) {
  //         alert(temData.msg);
  //         return;
  //       }
  //     } catch (error) {
  //       console.error(error);
  //     }
  //   };
  //   getData();
  // }, []);

  //modal中select选项
  const constellations = [
    { label: "白羊座", value: "白羊座" },
    { label: "金牛座", value: "金牛座" },
    { label: "双子座", value: "双子座" },
    { label: "巨蟹座", value: "巨蟹座" },
    { label: "狮子座", value: "狮子座" },
    { label: "处女座", value: "处女座" },
    { label: "天秤座", value: "天秤座" },
    { label: "天蝎座", value: "天蝎座" },
    { label: "射手座", value: "射手座" },
    { label: "摩羯座", value: "摩羯座" },
    { label: "水瓶座", value: "水瓶座" },
    { label: "双鱼座", value: "双鱼座" },
  ];
  const provinces = [
    { label: "北京市", value: "北京市" },
    { label: "天津市", value: "天津市" },
    { label: "河北省", value: "河北省" },
    { label: "山西省", value: "山西省" },
    { label: "内蒙古自治区", value: "内蒙古自治区" },
    { label: "辽宁省", value: "辽宁省" },
    { label: "吉林省", value: "吉林省" },
    { label: "黑龙江省", value: "黑龙江省" },
    { label: "上海市", value: "上海市" },
    { label: "江苏省", value: "江苏省" },
    { label: "浙江省", value: "浙江省" },
    { label: "安徽省", value: "安徽省" },
    { label: "福建省", value: "福建省" },
    { label: "江西省", value: "江西省" },
    { label: "山东省", value: "山东省" },
    { label: "河南省", value: "河南省" },
    { label: "湖北省", value: "湖北省" },
    { label: "湖南省", value: "湖南省" },
    { label: "广东省", value: "广东省" },
    { label: "广西壮族自治区", value: "广西壮族自治区" },
    { label: "海南省", value: "海南省" },
    { label: "重庆市", value: "重庆市" },
    { label: "四川省", value: "四川省" },
    { label: "贵州省", value: "贵州省" },
    { label: "云南省", value: "云南省" },
    { label: "西藏自治区", value: "西藏自治区" },
    { label: "陕西省", value: "陕西省" },
    { label: "甘肃省", value: "甘肃省" },
    { label: "青海省", value: "青海省" },
    { label: "宁夏回族自治区", value: "宁夏回族自治区" },
    { label: "新疆维吾尔自治区", value: "新疆维吾尔自治区" },
    { label: "台湾省", value: "台湾省" },
    { label: "香港特别行政区", value: "香港特别行政区" },
    { label: "澳门特别行政区", value: "澳门特别行政区" },
  ];
  //modal中平台checkbox名称
  const platformList = ["抖音", "微博", "哔哩哔哩", "快手", "秘live"];
  //表头可见性表单的checkbox选项
  const showColumnsOptions = [
    {
      label: "基础信息",
      value: "baseInfo",
    },
    {
      label: "个人展示信息",
      value: "displayInfo",
    },
    {
      label: "分成比例",
      value: "shareRatio",
    },
    {
      label: "平台",
      value: "platform",
    },
    {
      label: "封面图片",
      value: "displayPoster",
    },
    {
      label: "封面视频",
      value: "displayVideo",
    },
    {
      label: "相册",
      value: "displayGallery",
    },
    {
      label: "备注",
      value: "remark",
    },
  ];
  //展示的数据
  const [showData, setShowData] = useState(data);
  //搜索名人
  const search = (value) => {
    value.name || value.mid
      ? setShowData(
          data.filter(
            (item) =>
              item.baseInfo.name === value.name ||
              item.baseInfo.mid === value.mid
          )
        )
      : setShowData(data);
  };
  //表单提交失败
  const onFinishFailed = (errorInfo) => {
    console.log("Failed:", errorInfo);
  };
  //modal是否展示
  const [isModalOpen, setIsModalOpen] = useState(false);
  //点击modal取消按钮
  const handleCancel = () => {
    setIsModalOpen(false);
  };
  //modal打开时的默认值
  const [defaultValues, setDefaultValues] = useState({});
  //点击修改按钮
  const handleModal = (record) => {
    setDefaultValues(record);
    const streamerPlatforms = record.platform.map((item) => item.name);
    setIsModalOpen(true);
  };
  //表单提交成功
  const onModalFormFinish = (value) => {
    //处理表单格式
    //上传表单操作...
    console.log("Success:", value);
    //关闭模态
    setIsModalOpen(false);
  };
  //表单提交失败
  const onModalFormFinishFailed = (errorInfo) => {
    console.log("Failed:", errorInfo);
  };

  //保存上传的封面id
  const [ids, setIds] = useState([]);

  return (
    <div style={{ marginLeft: 20, marginRight: 20 }}>
      <div style={{ marginTop: 20, marginBottom: 10 }}>
        <p style={{ display: "inline" }}>数据可见性：</p>
        <Checkbox.Group
          options={showColumnsOptions}
          defaultValue={showColumns}
          onChange={(value) => setShowColumns(value)}
        />
      </div>
      <Form name="search" onFinish={search} onFinishFailed={onFinishFailed}>
        <Space style={{ marginBottom: 20 }}>
          <Form.Item label="mid" name="mid" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Form.Item label="昵称" name="name" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Button type="primary" htmlType="submit">
            搜索
          </Button>
        </Space>
      </Form>
      <Table
        columns={dynamicColumns}
        dataSource={showData}
        pagination={{ pageSize: 20 }}
        scroll={{ y: window.innerHeight - 300 }}
      />
      {/* 模态框是否显示 */}
      {isModalOpen && (
        <Form
          name="change"
          onFinish={onModalFormFinish}
          onFinishFailed={onModalFormFinishFailed}
          autoComplete="off"
        >
          <Modal
            title="修改资料"
            cancel={handleCancel}
            content={
              <div
                className="flex flex-col overflow-y-scroll"
                style={{ height: (window.innerHeight * 2) / 3 }}
              >
                <div className="flex flex-row">
                  <Image width={80} src={defaultValues.baseInfo.avatar} />
                  <div className="flex flex-col justify-between ml-2">
                    <p className="font-bold">
                      mid：{defaultValues.baseInfo.mid}
                    </p>
                    <p className="font-bold">
                      昵称：{defaultValues.baseInfo.name}
                    </p>
                    <p className="font-bold">
                      联系方式：{defaultValues.baseInfo.contact}
                    </p>
                    <p className="font-bold">
                      入驻时间：{defaultValues.baseInfo.joinTime}
                    </p>
                  </div>
                </div>
                <div
                  className="flex flex-row flex-wrap"
                  style={{ width: (window.innerWidth * 2) / 3 }}
                >
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="fans"
                    label="全网粉丝（万）"
                    initialValue={defaultValues.displayInfo.fans}
                    rules={[
                      {
                        required: true,
                        message: "请输入全网粉丝数量",
                      },
                    ]}
                  >
                    <InputNumber min={0} />
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="wechat"
                    label="微信号"
                    initialValue={defaultValues.displayInfo.wechat}
                    rules={[
                      {
                        required: true,
                        message: "请输入微信号",
                      },
                    ]}
                  >
                    <Input />
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="signature"
                    label="个性签名"
                    initialValue={defaultValues.displayInfo.signature}
                    rules={[
                      {
                        required: true,
                        message: "请输入个性签名",
                      },
                    ]}
                  >
                    <Input />
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="age"
                    label="年龄"
                    initialValue={defaultValues.displayInfo.age}
                    rules={[
                      {
                        required: true,
                        message: "请填写年龄",
                      },
                    ]}
                  >
                    <InputNumber min={18} max={60} />
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="height"
                    label="身高（cm）"
                    initialValue={defaultValues.displayInfo.height}
                    rules={[
                      {
                        required: true,
                        message: "请填写身高",
                      },
                    ]}
                  >
                    <InputNumber min={140} max={200} />
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="weight"
                    label="体重（kg）"
                    initialValue={defaultValues.displayInfo.weight}
                    rules={[
                      {
                        required: true,
                        message: "请填写体重",
                      },
                    ]}
                  >
                    <InputNumber min={35} max={100} />
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="constellation"
                    label="星座"
                    initialValue={defaultValues.displayInfo.constellation}
                    rules={[
                      {
                        required: true,
                        message: "请填写星座",
                      },
                    ]}
                  >
                    <select
                      style={{
                        height: 32,
                        padding: "4px 11px",
                        border: "1px solid #d9d9d9",
                        borderRadius: 4,
                        outline: "none",
                      }}
                    >
                      {constellations.map((item) => (
                        <option key={item.value} value={item.value}>
                          {item.label}
                        </option>
                      ))}
                    </select>
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="location"
                    label="居住地"
                    initialValue={defaultValues.displayInfo.location}
                    rules={[
                      {
                        required: true,
                        message: "请填写居住地",
                      },
                    ]}
                  >
                    <select
                      style={{
                        height: 32,
                        padding: "4px 11px",
                        border: "1px solid #d9d9d9",
                        borderRadius: 4,
                        outline: "none",
                      }}
                    >
                      {provinces.map((item) => (
                        <option key={item.value} value={item.value}>
                          {item.label}
                        </option>
                      ))}
                    </select>
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="shareRatio"
                    label="分成比例（%）"
                    initialValue={defaultValues.shareRatio}
                    rules={[
                      {
                        required: true,
                        message: "请填写分成比例",
                      },
                    ]}
                  >
                    <InputNumber min={0} max={100} />
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="remark"
                    label="备注"
                    initialValue={defaultValues.remark}
                  >
                    <Input />
                  </Form.Item>
                </div>
                <div>
                  <Form.Item
                    className="px-2"
                    name="displayPoster"
                    label="封面图片链接"
                    initialValue={defaultValues.displayPoster}
                    rules={[
                      {
                        required: true,
                        message: "请输入封面图片链接",
                      },
                    ]}
                  >
                    <Input />
                  </Form.Item>
                  <VideoUploader setIds={setIds} />
                  <Form.Item
                    className="px-2"
                    name="displayVideo"
                    label="封面视频链接"
                    initialValue={defaultValues.displayVideo}
                    rules={[
                      {
                        required: true,
                        message: "请输入封面视频链接",
                      },
                    ]}
                  >
                    <Input />
                  </Form.Item>
                  <Form.Item
                    className="px-2"
                    name="displayGallery"
                    label="相册图片链接（用空格分割）"
                    initialValue={defaultValues.displayGallery.join(" ")}
                    rules={[
                      {
                        required: true,
                        message: "请输入相册图片链接（用空格分割）",
                      },
                    ]}
                  >
                    <TextArea rows={4} />
                  </Form.Item>
                  <Form.List
                    name="platform111"
                    initialValue={defaultValues.platform}
                  >
                    {(fields, { add, remove }) => (
                      <>
                        {fields.map(({ key, name }) => (
                          <Space
                            key={key}
                            style={{
                              display: "flex",
                              marginBottom: 8,
                            }}
                            align="baseline"
                          >
                            <Form.Item
                              label="顺序"
                              name={[name, "index"]}
                              rules={[
                                {
                                  required: true,
                                  message: "请输入顺序",
                                },
                              ]}
                            >
                              <InputNumber min={0} />
                            </Form.Item>
                            <Form.Item
                              label="平台"
                              name={[name, "name"]}
                              rules={[
                                {
                                  required: true,
                                  message: "请选择平台名称",
                                },
                              ]}
                            >
                              <select
                                style={{
                                  height: 32,
                                  padding: "4px 11px",
                                  border: "1px solid #d9d9d9",
                                  borderRadius: 4,
                                  outline: "none",
                                }}
                              >
                                {platformList.map((item) => (
                                  <option key={item} value={item}>
                                    {item}
                                  </option>
                                ))}
                              </select>
                            </Form.Item>
                            <Form.Item
                              label="昵称"
                              name={[name, "id"]}
                              rules={[
                                {
                                  required: true,
                                  message: "请输入昵称",
                                },
                              ]}
                            >
                              <Input />
                            </Form.Item>
                            <Form.Item
                              label="链接"
                              name={[name, "url"]}
                              rules={[
                                {
                                  required: true,
                                  message: "请输入链接",
                                },
                              ]}
                            >
                              <Input />
                            </Form.Item>
                            <MinusCircleOutlined
                              className="text-xl text-red-400"
                              onClick={() => remove(name)}
                            />
                          </Space>
                        ))}
                        <Form.Item>
                          <Button
                            type="dashed"
                            icon={<PlusOutlined />}
                            onClick={() => add()}
                            block
                          >
                            添加平台
                          </Button>
                        </Form.Item>
                      </>
                    )}
                  </Form.List>
                </div>
              </div>
            }
          />
        </Form>
      )}
    </div>
  );
};

export default function StreamerManagement() {
  return <GoodsContent />;
}
